"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GoogleMapNodeParser = void 0;
const _1 = require(".");
const googleMapRegExp = /^(?<left>.*?)\[(?<latitude>([NS]\d+(\.\d+)?),(?<longitude>[EW]\d+(\.\d+)?)(?<zoom>(,Z\d+)?))(?<place>)\](?<right>.*)$/;
const leftGoogleMapRegExp = /^(?<left>.*?)\[(?<place>[^\]]*[^\s])\s+(?<latitude>([NS]\d+(\.\d+)?),(?<longitude>[EW]\d+(\.\d+)?)(?<zoom>(,Z\d+)?))\](?<right>.*)$/;
const rightGoogleMapRegExp = /^(?<left>.*?)\[(?<latitude>([NS]\d+(\.\d+)?),(?<longitude>[EW]\d+(\.\d+)?)(?<zoom>(,Z\d+)?))\s+(?<place>[^\]]*[^\s])\](?<right>.*)$/;
const isGoogleMapMatch = (obj) => { var _a; return ((_a = obj === null || obj === void 0 ? void 0 : obj.groups) === null || _a === void 0 ? void 0 : _a.latitude) !== undefined; };
const createGoogleMapNode = (_latitude, _longitude, _zoom, place) => {
    const latitude = parseFloat(_latitude.replace(/^N/, '').replace(/^S/, '-'));
    const longitude = parseFloat(_longitude.replace(/^E/, '').replace(/^W/, '-'));
    const zoom = /^,Z\d+$/.test(_zoom)
        ? parseInt(_zoom.replace(/^,Z/, ''), 10)
        : 14;
    const url = place !== ''
        ? `https://www.google.com/maps/place/${encodeURIComponent(place)}/@${latitude},${longitude},${zoom}z`
        : `https://www.google.com/maps/@${latitude},${longitude},${zoom}z`;
    return {
        type: 'googleMap',
        latitude,
        longitude,
        zoom,
        place,
        url
    };
};
exports.GoogleMapNodeParser = (text, { nested, quoted }, next) => {
    var _a, _b;
    if (nested)
        return next();
    const googleMapMatch = (_b = (_a = text.match(googleMapRegExp)) !== null && _a !== void 0 ? _a : text.match(leftGoogleMapRegExp)) !== null && _b !== void 0 ? _b : text.match(rightGoogleMapRegExp);
    if (!isGoogleMapMatch(googleMapMatch))
        return next();
    const { left, latitude, longitude, zoom, place, right } = googleMapMatch.groups;
    return [
        ..._1.convertToLineNodes(left, { nested, quoted }),
        createGoogleMapNode(latitude, longitude, zoom, place),
        ..._1.convertToLineNodes(right, { nested, quoted })
    ];
};
//# sourceMappingURL=GoogleMapNode.js.map